@@ -9,12 +9,10 @@ from flask_jwt_extended import (
     get_jwt_identity,
     jwt_required,
 )
-from uwsgidecorators import filemon, postfork
+from uwsgidecorators import filemon
 
 import threat_db.graphclient as graph_client
 import threat_db.loader as data_loader
-
-# import threat_db.client as db_client
 from threat_db.config import JWT_ACCESS_TOKEN_EXPIRES_HOURS
 from threat_db.logger import LOG
 
@@ -45,7 +43,6 @@ else:
 jwt = JWTManager(app)
 
 transport, client = graph_client.get(DGRAPH_GRAPHQL_HOST, os.getenv("DGRAPH_API_KEY"))
-# client_stub, dqlclient = db_client.get(DGRAPH_RPC_HOST)
 
 
 def allowed_file(filename):
@@ -87,14 +84,8 @@ def process_file(file):
             "success": "false",
             "message": f"File is not a supported type. Supported types are {', '.join(ALLOWED_EXTENSIONS)}",
         }, 500
-    result = False
     result = data_loader.process_vex_file(client, file.stream)
-    if not result:
-        return {
-            "success": "false",
-            "message": "File was not processed successfully",
-        }, 500
-    return {"success": "true"}
+    return result
 
 
 if DGRAPH_GRAPHQL_HOST in ("http://dgraph-standalone:8080/graphql"):
@@ -110,15 +101,21 @@ if DGRAPH_GRAPHQL_HOST in ("http://dgraph-standalone:8080/graphql"):
 @jwt_required()
 def import_data():
     current_user = get_jwt_identity()
-    files = request.files
+    files = request.files.getlist("file")
+    if not files:
+        return {
+            "success": "false",
+            "message": "Upload files to import using the file attribute",
+        }, 500
     # check if the post request has the file part
-    if "file" in files:
-        file = files["file"]
-        return process_file(file)
-    return {
-        "success": "false",
-        "message": "Upload files to import using the file attribute",
-    }, 500
+    for uf in files:
+        result = process_file(uf)
+        if not result:
+            return {
+                "success": "false",
+                "message": "File was not processed successfully",
+            }, 500
+    return jsonify(success=True)
 
 
 @app.route("/graphql", methods=["POST"])
@@ -139,7 +136,12 @@ if THREATDB_DATA_DIR and os.path.exists(THREATDB_DATA_DIR):
 
         @filemon(THREATDB_DATA_DIR)
         def data_drop(signum):
-            data_loader.start(client, THREATDB_DATA_DIR, remove_on_success=True)
+            try:
+                data_loader.start(client, THREATDB_DATA_DIR, remove_on_success=True)
+            except Exception:
+                LOG.debug(
+                    f"Error processing the files in {THREATDB_DATA_DIR}. This is usually due to duplicate invocations."
+                )
 
     else:
         LOG.warn(
